Title: Introduction
Date: 2018-04-8 15:15:13
Category: Doc
Tags: Doc,English,Chinese

# Welcome to GeoPyTool

[![Build Status](https://travis-ci.org/GeoPyTool/GeoPyTool.svg?branch=master)](https://travis-ci.org/GeoPyTool/GeoPyTool)

![](https://github.com/GeoPyTool/GeoPyTool/blob/master/images/Samples.png?raw=true)





## Introduction

GeoPyTool is an application based on Python and designed as a solution for geology related daily work. **It can run on alomost all mainstream operating systems**, such as Windows 7 SP1, Windows 8, Windows 10, macOS Sierra, macOS High Sierra, Ubuntu Linux, Debian Linux, Fedora Linux, and alomost all other widely used desktop platforms.

**GeoPyTool doesn't rely on any other software**, such as MS Excel or CorelDraw, it can directly transport your data into the plot as vector graphic files and the calculation results into data sheets such as Xlsx or CSV files.

It is a **free software**: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

GeoPyTool contains both traditional routines and newly developed methods。


### [Packed Application](http://geopytool.com/installation.html)

### [PIP Installation](http://geopytool.com/installation-expert.html)

### [Demonstration](http://geopytool.com/demonstration.html)



## 简介

GeoPyTool 是一个基于 Python 实现的开源应用，针对的是地质学研究中的日常用途。由于使用了 Python，天生跨平台天赋加持，所以几乎能运行于所有主流操作系统，比如 Windows 7 SP1, Windows 8, Windows 10, macOS Sierra, macOS High Sierra, Ubuntu Linux, Debian Linux, Fedora Linux 等等几乎全部主流的桌面操作系统。

GeoPyTool 不需依赖任何其他软件，不像 GeoKit 那样依赖特定版本的 32bit 的 Office，也不像 CGDK 那样需要依赖 CorelDRAW 的安装，单独有 GeoPyTool 一个，就可以实现从原始数据到出矢量图，以及导出各种计算的结果为 Xlsx 或者 CSV 这种表格文件。

GeoPyTool 是一个自由软件:您可以根据自由软件基金会发布的GNU通用公共许可证的条款重新发布或者对其进行修改，但必须也基于同样的 GPLV3（GNU通用公共许可证第三版 ） ，或者更新版本的 GNU General Public License。

GeoPyTool 包含了一些常用的传统方法，也实现了一些近年来新诞生的研究成果。

### [打包程序](http://geopytool.com/an-zhuang-zhi-nan.html)

### [代码安装](http://geopytool.com/an-zhuang-zhi-nan-jin-jie.html)

### [使用指南](http://geopytool.com/yan-shi-shi-pin.html)




### GeoPyTool pack for Windows:
[Baidu Download 百度网盘](https://pan.baidu.com/s/1O4Db0punGIeoX4i1GKjNnw)

[Google Drive](https://drive.google.com/open?id=1NyjUdAuCVLrAPav81I1pljM6zL3yR-RP)




### GeoPyTool app for macOS:
[Baidu Download 百度网盘](https://pan.baidu.com/s/1R9gCNui4p8zz4-xegmxhZA)

[Google Drive](https://drive.google.com/open?id=1qbRJPIrBOxTKIgJWNNPFBrkpPbB3M_17)



# 捐助支持

如果你希望支持 GeoPyTool 的开发，可以扫描下面的二维码进行捐助。
![](https://raw.githubusercontent.com/GeoPyTool/GeoPyTool/master/img/WeChatQrCode.png)


